"""
Ref: The Schrodinger Equation: First Steps
     By Graham W Griffiths, May 2023, available at: www.pdecomp.net
This python code produces Matter Wave plots - Fig. 1.1.
"""

import numpy as np
import matplotlib.pyplot as plt

def matterWaves(dat):
  # constants
  h = 6.62607015 * 10**(-34)
  c = 2.99793E8
  m = 9.11E-31
  
  # data
  r,v,E = dat
  f = E/h
  p = m*v
  lamb = h/p
  circ = 2*np.pi*r
  n = np.round(circ/lamb)
  
  return(f,lamb,n)

#                n     r[m]      v[m/s]      E[J]       E[eV]
mDat = np.array([[1, 5.292E-11, 2.188E+06, 2.180E-18, -13.6068],
                 [2, 2.117E-10, 1.094E+06, 5.450E-19, - 3.4017],
                 [3, 4.763E-10, 7.292E+05, 2.422E-19, - 1.5119],
                 [4, 8.467E-10, 5.469E+05, 1.362E-19, - 0.8504],
                 [5, 1.323E-09, 4.375E+05, 8.719E-20, - 0.5443],
                 [6, 1.905E-09, 3.646E+05, 6.055E-20, - 0.3780]] )

for N in range(1,7) :
  f,lamb, n = matterWaves(mDat[N-1,[1,2,3]])
  print(f"n={n:1.0f}, lamb={lamb:1.4e}, f={f:1.4e}")


# Results
# -------------------------------------
# n=1, lamb=3.3242e-10, f=3.2900e+15
# n=2, lamb=6.6484e-10, f=8.2251e+14
# n=3, lamb=9.9745e-10, f=3.6553e+14
# n=4, lamb=1.3299e-09, f=2.0555e+14
# n=5, lamb=1.6625e-09, f=1.3159e+14
# n=6, lamb=1.9949e-09, f=9.1381e+13