"""
Ref: The Schrodinger Equation: First Steps
     By Graham W Griffiths, May 2023, available at: www.pdecomp.net 
This python code produces Hydrogen Energy Level plots - Fig. 2.1.
Uses HydrogenicAtom_class.py 

"""


import numpy as np
import HydrogenicAtom_class as hc
import matplotlib.pyplot as plt
from matplotlib import cm

N = 7
ys = []
for n in range(1, N):
    ha = hc.HydrogenicAtom(n=n)
    _, ev = ha.energy()
    ys.append((n, round(ev, 2)))

fig, ax = plt.subplots(nrows=1, ncols=1, figsize=(4, 10))
ax.set_ylim(-14.0, 0.0)
ax.set_xticks([])
ax.set_yticks([-13.61,-3.40,-1.51,-0.85,-0.54,-0.38,0.0])
ax.tick_params(axis='both', which='major', labelsize=12)
ax.set_ylabel('En, [eV]', size=16, color='k')
ax.set_title(f'Hydrogen Energy Levels,\n n=1 to n={N-1}', size=16, color='k')
for y in ys:
    ax.axhline(y[1], color='r')
    
plt.tight_layout()