"""
Ref: The Schrodinger Equation: First Steps
     By Graham W Griffiths, May 2023, available at: www.pdecomp.net
This python code produces Wave Function and Probability Density function
Potential Well plots for the 1D Particle in a Box - Fig. 4.2.
"""


import numpy as np
import matplotlib
import matplotlib.pyplot as plt
matplotlib.rcParams.update({'font.size': 14})
from mayavi import mlab

n = np.array([1,2,3,4,5])
L = 10e-9
h = 6.62607015 * 10**(-34)
m = 9.10938370 * 10**(-31)
J_to_eV = 6.242*10**18

n_text = r'$n$=%d' % (n[0])

def psi(x, nx) :
  psi = np.sqrt(8/(L)) * np.sin(nx * np.pi * x/L)
  return psi/5000

def E(x,nx) :
  return nx**2 * h**2/(8*m*L**2) * J_to_eV

N = 50
x = np.linspace(0,L,N)



g = E(x, n)

fig, (ax1, ax2) = plt.subplots(1, 2,figsize=(10,8))#, constrained_layout=True)
ax1.set_ylim(0,110)
ax2.set_ylim(0,110)
fig.tight_layout(pad=5.0)
# plt.subplots_adjust(right=.8)
ax1.set_ylabel("Energy levels, $E_n$ [meV]")
ax1.set_xlabel("Length, $x$ [m]")
ax2.set_ylabel("Energy levels, $E_n$ [meV]")
ax2.set_xlabel("Length, $x$ [m]")



for i in range(5) :
  ge = g[i]*1000
  f1 = psi(x, n[i])+g[i]*1000
  f2 = (psi(x, n[i])**2)/4+ge
  e  = np.ones(N)*ge
  ax1.plot(x, f1, '-b') 
  ax1.plot(x, e,  '-k') 
  ax2.plot(x, f2, '-b') 
  ax2.plot(x, e,  '-k') 
  ax1.text(1.05, f1[0]/110, r"n=%d"%n[i], transform=ax1.transAxes)
  ax2.text(2.6, f1[0]/110, r"n=%d"%n[i], transform=ax1.transAxes)

ax1.set_title(r"Wave Functions, $\psi$")
ax2.set_title(r"Probability Density Functions, $\rho$")
fig.suptitle('Wave Functions and Probability Density Functions \nSuperimposed on Energy levels.',
             fontsize=22, y=1)
plt.subplots_adjust(top=0.85)

