"""
Ref: The Schrodinger Equation: First Steps
     By Graham W Griffiths, May 2023, available at: www.pdecomp.net 
This python code produces Wave Function and Probability Density function
Potential Well plots for the 3D Particle in a Box (Cartesian) - Fig. 4.23.and
Fig. 4.4
"""


import numpy as np
from mayavi import mlab

nx, ny, nz = [3,3,3]
Lx, Ly, Lz = np.array([1,1,1])*1e-8 # normalized

n_text = r'nx=%d, ny=%d, nz=%d' % (nx,ny,nz)

def fun(x, y, z):
  psi = np.sqrt(8/(Lx * Ly * Lz)) * np.sin(nx * np.pi * x/Lx) * \
                                    np.sin(ny * np.pi * y/Ly) * \
                                    np.sin(nz * np.pi * z/Lz)
  return psi
N = 100j
x, y, z = np.mgrid[0:Lx:N, 0:Ly:N, 0:Lz:N]

f0 = np.real(fun(x,y,z))      # wave function
f1 = np.abs(fun(x,y,z))**2    # prbability density function
f = f1
masky = np.select([y>Ly*3/4], [np.nan],default=1)# (0,1,3)
pltType = 1
mlab.figure(size=[800,800], bgcolor=(1,1,1), fgcolor=(0.,0.,0.)) # size in px
if pltType == 1 :
  p = mlab.contour3d(x,y,z,f*masky,contours=10, opacity=1, colormap="jet", 
                      reset_zoom=True) 
else :
  p = mlab.points3d(x,y,z,f, opacity=1, colormap="plasma", 
                      reset_zoom=True,scale_factor=0.01,scale_mode='scalar',
                      mode='2dcircle') 

mlab.outline(p ,extent=(0,Lx ,0,Ly, 0,Lz) )
# p.actor.actor.property.set( specular=1.0, specular_power=128.)  #, line_width=1, 
p.actor.property.specular=1
p.actor.property.specular_power=128
mlab.title(n_text,size=0.3, height=0.9)

# mlab.view(azimuth=45, elevation=45, distance=5.0)
mlab.view(azimuth=110, elevation=65, distance=4.7e-8) # (3,1.3)
# mlab.view(azimuth=40, elevation=58, distance=4.2e-8) # (1,2,3)
axes = mlab.axes()
axes.axes.corner_offset = 0.1
cb = mlab.colorbar(orientation='vertical', nb_labels=5) #, label_fmt='%.1f')
cb.scalar_bar.unconstrained_font_size = True
cb.label_text_property.font_size=18


#mlab.show()
#mlab.close() # closes plot window