"""
Ref: The Schrodinger Equation: First Steps
     By Graham W Griffiths, May 2023, available at: www.pdecomp.net 
This python code produces plots of the Radial part of Wave Functions
for the Hydrogen Atom - Fig. 8.2
Adapted from:
  https://www.desmos.com/calculator/qtg1iagj1m

"""

import numpy as np
import math
import scipy.special as sp
import matplotlib.pyplot as plt


def radialWF(n,ell,r,a):
  if(n-ell-1 == 1000):
    G = 1 #np.ones(N)
  else :
    G = sp.genlaguerre(n-ell-1,2*ell+1)(2*r/(n*a))
  R = np.sqrt(((2/(n*a))**3*math.factorial(n-ell-1)) / \
              (2*n*math.factorial(n+ell)))* \
              np.exp(-r/(n*a))*(2*r/(n*a))**ell*G
  # Or, equivently,  
  # R2 = np.sqrt((4*math.factorial(n-ell-1))/ \
  #             (a**3*n**4*math.factorial(n+ell)))* \
  #             np.exp(-r/(n*a))*(2*r/(n*a))**ell*G
  return R

N = 100
a =  1 # a0 = 0.529E-10 [Angstom], normalized to unity
roa = np.linspace(0, 20, N)
r = roa*a

# R21 = 1/np.sqrt(24) * a**(-3/2) * (r/a) *np.exp(-r/(2*a)) # D Griffith, p141 
# R30 = (2/27)*(1/(3*a))**(3/2)*(27-18*r/a+2*(r/a)**2)*np.exp(-r/(3*a))
# R31 = (1/27)*(2/3*a)**(3/2)*(r/a)*(6-r/a)*np.exp(-r/(3*a))
# R32 = (4/(27*np.sqrt(10)))*(1/3*a)**(3/2)*(r/a)**2*np.exp(-r/(3*a))

fig, ax1 = plt.subplots(1, 1,figsize=(10,8))
plt.rc('font', size=14)
plt.rc('axes', labelsize=14)
plt.rc('xtick', labelsize=14)
for n in range(1,4) :
  for ell in range(n):
    print(f"n={n}, ell={ell}")
    Rtxt = f"R{n}{ell}"
    Rnl = radialWF(n,ell,r,a)
    ax1.plot(roa,Rnl,linewidth=3,label=Rtxt)

# ax1.plot(roa,R30,'--k',linewidth=3,label='R30x')
# ax1.plot(roa,R31,'--y',linewidth=3,label='R31x')
# ax1.plot(roa,R32,'--b',linewidth=3,label='R32x')

ax1.set_xlabel("r/a",fontsize=16)
ax1.set_ylabel(r"$R_{nl}(r)$",fontsize=16)
ax1.set_ylim([-0.1,0.5])
plt.grid()
plt.legend()