"""
Ref: The Schrodinger Equation: First Steps
     By Graham W Griffiths, May 2023, available at: www.pdecomp.net 
This python code produces Probability Density function plots for the 
Classical Simple Harmonic Oscillator - Fig. A.1.

"""

import numpy as np
import matplotlib.pyplot as plt
plt.rcParams.update({'font.size': 14}) #, 'font.family': 'STIXGeneral', 'mathtext.fontset': 'stix'})

N = 200
amax = 6
fig, ax = plt.subplots()
for i in range(3,amax+1):
  
  xmax = i; xmin =-xmax
  
  x = np.linspace(xmin, xmax, N, dtype=float)
  a = xmax
  p = np.zeros([N])
  
  # p = (1/np.pi)/np.sqrt(a**2-x**2 + 0.1)
  b = np.pi*np.sqrt(a**2-x**2)
  c = np.ones([N],dtype=float)
  
  # Check for divide by zero
  for j in range(N):
    if b[j] > 0:
      p[j] = c[j]/b[j]
    else:
      p[j] = np.nan
  
  ax.plot(x, p, linewidth=2, label=f'$a=${a}')

ax.set_xlim([-amax,amax])
ax.set_xlabel(r'displacement, $x$')
ax.set_ylabel(r'$\rho=\dfrac{1}{\pi\sqrt{a^2-x^2}}$')        
ax.set_title('PDF for Classical SHM')

ax.legend()
ax.grid()
plt.tight_layout()
plt.show()